@@ -50,6 +50,10 @@ class ContentSecurityService(Service):
                     "AsyncLiveAudioRisk": ApiInfo("POST", "/", {"Action": "AsyncLiveAudioRisk", "Version": "2022-04-25"}, {}, {}),
                     "GetAudioLiveResult": ApiInfo("GET", "/", {"Action": "GetAudioLiveResult", "Version": "2022-04-25"}, {}, {}),
                     "TextSliceRisk": ApiInfo("POST", "/", {"Action": "TextSliceRisk", "Version": "2022-11-07"}, {}, {}),
+                    "AsyncImageRiskV2": ApiInfo("POST", "/", {"Action": "AsyncImageRisk", "Version": "2022-08-26"}, {}, {}),
+                    "ImageResultV2": ApiInfo("GET", "/", {"Action": "ImageResult", "Version": "2022-08-26"}, {}, {}),
+                    "CloseAudioLiveRisk": ApiInfo("POST", "/", {"Action": "CloseAudioLive", "Version": "2022-04-25"}, {}, {}),
+                    "CloseVideoLiveRisk": ApiInfo("POST", "/", {"Action": "CloseVideoLive", "Version": "2022-04-25"}, {}, {}),
                     }
 
         return api_info
@@ -97,6 +101,25 @@ class ContentSecurityService(Service):
         res_json = json.loads(res)
         return res_json
 
+    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
+                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
+    def async_image_risk_v2(self, params, body):
+        res = self.json("AsyncImageRiskV2", params, json.dumps(body))
+        if res == '':
+            raise Exception("empty response")
+        res_json = json.loads(res)
+        return res_json
+
+    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
+                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
+    def image_result_v2(self, params, body):
+        res = self.get("ImageResultV2", params, json.dumps(body))
+        if res == '':
+            raise Exception("empty response")
+        res_json = json.loads(res)
+        return res_json
+
+
     @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                     retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
     def text_risk(self, params, body):
@@ -170,14 +193,14 @@ class ContentSecurityService(Service):
         return res_json
 
     def live_audio_result(self, params, body):
-        res = self.get("GetVideoLiveResult", params, json.dumps(body))
+        res = self.get("GetAudioLiveResult", params, json.dumps(body))
         if res == '':
             raise Exception("empty response")
         res_json = json.loads(res)
         return res_json
 
     def live_video_result(self, params, body):
-        res = self.get("GetAudioLiveResult", params, json.dumps(body))
+        res = self.get("GetVideoLiveResult", params, json.dumps(body))
         if res == '':
             raise Exception("empty response")
         res_json = json.loads(res)
@@ -189,3 +212,17 @@ class ContentSecurityService(Service):
             raise Exception("empty response")
         res_json = json.loads(res)
         return res_json
+
+    def close_video_live_risk(self, params, body):
+        res = self.json("CloseVideoLiveRisk", params, json.dumps(body))
+        if res == '':
+            raise Exception("empty response")
+        res_json = json.loads(res)
+        return res_json
+
+    def close_audio_live_risk(self, params, body):
+        res = self.json("CloseAudioLiveRisk", params, json.dumps(body))
+        if res == '':
+            raise Exception("empty response")
+        res_json = json.loads(res)
+        return res_json
\ No newline at end of file
